@@ -16,7 +16,7 @@ from urllib3.util.retry import Retry
 from tqdm import tqdm
 import ntpath
 
-__version__ = "1.2.4"
+__version__ = "1.2.5"
 CONFIG_PATH = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                            ".canvassyncer.json")
 MAX_DOWNLOAD_COUNT = 8
@@ -256,9 +256,7 @@ class CanvasSyncer:
         res = {}
         page = 1
         if self.config.get('courseCodes'):
-            lowerCourseCodes = [
-                s.lower() for s in self.config['courseCodes']
-            ]
+            lowerCourseCodes = [s.lower() for s in self.config['courseCodes']]
             while True:
                 url = f"{self.baseurl}/courses?page={page}"
                 courses = self.sessGet(url).json()
@@ -366,13 +364,15 @@ class CanvasSyncer:
         for (fileUrl, path) in self.laterFiles:
             localCreatedTimeStamp = int(os.path.getctime(path))
             try:
-                try:
-                    newPath = os.path.join(
-                        ntpath.dirname(path),
-                        f"{localCreatedTimeStamp}_{ntpath.basename(path)}")
+                newPath = os.path.join(
+                    ntpath.dirname(path),
+                    f"{localCreatedTimeStamp}_{ntpath.basename(path)}")
+                if not os.path.exists(newPath):
                     os.rename(path, newPath)
-                except Exception as e:
-                    os.remove(path)
+                else:
+                    path = os.path.join(
+                        ntpath.dirname(path),
+                        f"{int(time.time())}_{ntpath.basename(path)}")
                 laterFiles.append((fileUrl, path))
             except Exception as e:
                 print(f"{e.__class__.__name__}! Skipped: {path}")
